@@ -57,11 +57,9 @@
 static void startManagerForKSecretD()
 {
     if (!QStandardPaths::findExecutable(QStringLiteral("kstart")).isEmpty()) {
-        QProcess::startDetached(QStringLiteral("kstart"), {QStringLiteral("kwalletmanager5"), QStringLiteral("--"), QStringLiteral("--KSecretD")});
-    } else if (!QStandardPaths::findExecutable(QStringLiteral("kstart5")).isEmpty()) {
-        QProcess::startDetached(QStringLiteral("kstart"), {QStringLiteral("kwalletmanager5"), QStringLiteral("--"), QStringLiteral("--KSecretD")});
+        QProcess::startDetached(QStringLiteral("kstart"), {QStringLiteral("--application"), QStringLiteral("kwalletmanager5-kwalletd")});
     } else {
-        QProcess::startDetached(QStringLiteral("kwalletmanager5"), QStringList{QStringLiteral("--KSecretD")});
+        QProcess::startDetached(QStringLiteral("kwalletmanager5"), QStringList{QStringLiteral("--kwalletd")});
     }
 }
 
